<?php
/*********************************************
 cpgShop Plugin for Coppermine Photo Gallery
 ********************************************
 written by Thomas Lange
 based on cpgmart by foulu

 ********************************************
 * @file $Id: cpgPayPal.class.php 82 2012-07-11 12:57:31Z Stramm $
 * @author $Author: Stramm $
 * @version $Revision: 82 $
 * @lastrevision $Date: 2012-07-11 14:57:31 +0200 (Mi, 11. Jul 2012) $
 * @modifiedby $LastChangedBy: Stramm $
 * @lastmodified $LastChangedDate: 2012-07-11 14:57:31 +0200 (Mi, 11. Jul 2012) $
 ********************************************
 cpgShop full Version 1.0.6
 **********************************************/

class cpgshop_paypal_class {

   var $last_error;                 // holds the last error
   var $ipn_log;                    // bool: log IPN results
   var $ipn_log_file;               // filename of the log
   var $ipn_response;               // holds the IPN response
   var $ipn_data = array();         // contains the POST values


   function cpgshop_paypal_class () {

      // initialization constructor.  Called when class is created.
	  global $CONFIG;
      $this->last_error = '';
      $this->ipn_log = $CONFIG['cpgshop_paypal_ipn_log'];
      $this->ipn_log_file = $CONFIG['cpgshop_paypal_ipn_log_file'];
      $this->ipn_response = '';
   }

   function cpgshop_validate_ipn() {
	  global $CONFIG;

	   	if ($CONFIG['cpgshop_paypal_test_mode'])
	   		$paypal_address = "https://www.sandbox.paypal.com/cgi-bin/webscr";
	   	else
	   		$paypal_address = "https://www.paypal.com/cgi-bin/webscr";

	      // parse the paypal URL
	      $url_parsed=parse_url($paypal_address);
	      // generate the post string from the _POST vars aswell as load the
	      // _POST vars into an arry so we can play with them from the calling
	      // script.
	      $post_string = '';


	   		$cage = Inspekt::makePostCage();
			foreach ($cage as $key2 => $value2){
				foreach ($value2 as $field => $value){
					$this->ipn_data["$field"] = $value;
					$post_string .= $field.'='.urlencode(stripslashes($value)).'&';
				}
			}

   	      $post_string.="cmd=_notify-validate"; // append ipn command

	      // open the connection to paypal
	      $fp = fsockopen($url_parsed[host],"80",$err_num,$err_str,30);
	      if(!$fp) {
	         // could not open the connection.  If loggin is on, the error message
	         // will be in the log.
	         $this->last_error = "fsockopen error no. $errnum: $errstr";
	         $this->cpgshop_log_ipn_results(false);
	         return false;

	      } else {
	         // Post the data back to paypal
	         fputs($fp, "POST $url_parsed[path] HTTP/1.1\r\n");
	         fputs($fp, "Host: $url_parsed[host]\r\n");
	         fputs($fp, "Content-type: application/x-www-form-urlencoded\r\n");
	         fputs($fp, "Content-length: ".strlen($post_string)."\r\n");
	         fputs($fp, "Connection: close\r\n\r\n");
	         fputs($fp, $post_string . "\r\n\r\n");

	         // loop through the response from the server and append to variable
	         while(!feof($fp)) {
	            $this->ipn_response .= fgets($fp, 1024);
	         }
	         fclose($fp); // close connection

      }

      if (eregi("VERIFIED",$this->ipn_response)) {

         // Valid IPN transaction.
         $this->cpgshop_log_ipn_results(true);
         return true;

      } else {
         // Invalid IPN transaction.  Check the log for details.
         $this->last_error = 'IPN Validation Failed.';
         $this->cpgshop_log_ipn_results(false);
         return false;

      }
   }

   function cpgshop_log_ipn_results($success) {

      if (!$this->ipn_log == '1') return;  // is logging turned off?

      // Timestamp
      $text = '['.date('m/d/Y g:i A').'] - ';

      // Success or failure being logged?
      if ($success) $text .= "SUCCESS!\n";
      else $text .= 'FAIL: '.$this->last_error."\n";

      // Log the POST variables
      $text .= "IPN POST Vars from Paypal:\n";
      foreach ($this->ipn_data as $key=>$value) {
         $text .= "$key=$value, ";
      }

      // Log the response from the paypal server
      $text .= "\nIPN Response from Paypal Server:\n ".$this->ipn_response;

      // Write to log
      $fp=fopen($this->ipn_log_file,'a');
      fwrite($fp, $text . "\n\n");

      fclose($fp);  // close file
   }
}

/**
*
 * @copyright Ivor Durham <ivor.durham@ivor.cc>
 * @copyright PayPal_Ahmad  (Nov. 04, 2006)
 * @copyright Unknown Modifier
 * @copyright Thomas Foerster <tf@1agency.de>
 * @copyright Thomas Lange <stramm@gmx.net>
 * @package PayPal
 */
class cpgshop_paypal_emp_class {
	private $certificate;	// Certificate resource
	private $certificateFile;	// Path to the certificate file
	private $privateKey;	// Private key resource (matching certificate)
	private $privateKeyFile;	// Path to the private key file
	private $paypalCertificate;	// PayPal public certificate resource
	private $paypalCertificateFile;	// Path to PayPal public certificate file
	private $certificateID; // ID assigned by PayPal to the $certificate.

	private $tempFileDirectory;

	public $error;

	/**
	 * Constructor
	 *
	 * @param string $certID The certificate ID assigned when the certificate was uploaded to PayPal
	 * @param string $pubCertFile The path to the client (public) certificate
	 * @param string $privCertFile The path to the private key corresponding to the certificate
	 * @param string $paypalCert The path to the PayPal certificate
	 */
	public function __construct($certID, $pubCertFile, $privCertFile, $paypalCert, $tempDir)
	{
		$this->error = 0;

		if ($certID != '')
		{
			$this->setCertificateID($certID);
		}

		if ($pubCertFile != '' && $privCertFile != '')
		{
			if (!$this->setCertificate($pubCertFile, $privCertFile))
			{
				$this->error = 1;
			}
		}

		if ($paypalCert != '')
		{
			if (!$this->setPayPalCertificate($paypalCert))
			{
				$this->error = 2;
			}
		}

		$this->tempFileDirectory = $tempDir;//$this->getTempDir();
	}

	/**
	 * Destructor
	 *
	 */
	public function __destruct()
	{

	}

	/**
	 * Sets the ID assigned by PayPal to the client certificate
	 *
	 * @param string $id The certificate ID assigned when the certificate was uploaded to PayPal
	 */
	public function setCertificateID($id)
	{
		$this->certificateID = $id;
	}

	/**
	 * set the client certificate and private key pair.
	 *
	 * @param string $certificateFilename The path to the client (public) certificate
	 * @param string $privateKeyFilename The path to the private key corresponding to the certificate
	 * @return bool TRUE if the private key matches the certificate, FALSE otherwise
	 */
	public function setCertificate($certificateFilename, $privateKeyFilename)
	{
		if (is_readable($certificateFilename) && is_readable($privateKeyFilename))
		{
			$handle = fopen($certificateFilename, "r");
			if ($handle === false)
				return false;

			$size = filesize($certificateFilename);
			$certificate = fread($handle, $size);
			@fclose($handle);

			unset($handle);

			$handle = fopen($privateKeyFilename, "r");
			if ($handle === false)
				return false;

			$size = filesize($privateKeyFilename);
			$privateKey = fread($handle, $size);
			@fclose($handle);

			if (($certificate !== false) && ($privateKey !== false) && openssl_x509_check_private_key($certificate, $privateKey))
			{
				$this->certificate     = $certificate;
				$this->certificateFile = $certificateFilename;
				$this->privateKey      = $privateKey;
				$this->privateKeyFile  = $privateKeyFilename;
				return true;
			}
		}
		else
		{
			return false;
		}
	}

	/**
	 * Sets the PayPal certificate
	 *
	 * @param string $fileName The path to the PayPal certificate
	 * @return bool TRUE if the certificate is read successfully, FALSE otherwise.
	 */
	public function setPayPalCertificate($fileName)
	{
		if (is_readable($fileName))
		{
			$handle = fopen($fileName, "r");
			if ($handle === false)
				return false;

			$size = filesize($fileName);

			$certificate = fread($handle, $size);
			if ($certificate === false)
				return false;

			fclose($handle);

			$this->paypalCertificate     = $certificate;
			$this->paypalCertificateFile = $fileName;

			return true;
		}
		else
		{
			return false;
		}
	}

	/**
	 * Sets the directory into which temporary files are written
	 *
	 * @param string $directory Directory in which to write temporary files
	 * @return bool TRUE if directory is usable
	 */
	public function setTempFileDirectory($directory)
	{
		if (is_dir($directory) && is_writable($directory))
		{
			$this->tempFileDirectory = $directory;
			return true;
		}
		else
		{
			return false;
		}
	}

	/**
	 * Using the previously set certificates and tempFileDirectory to encrypt the button information
	 *
	 * @param array $parameters Array with parameter names as keys
	 * @return mixed The encrypted string for the _s_xclick button form field OR false
	 */
	public function encryptButton($parameters)
	{
		// Check encryption data is available.

		if (($this->certificateID == '') || !isset($this->certificate) || !isset($this->paypalCertificate))
			return false;

		$clearText = '';
		$encryptedText = '';

		// initialize data.
		$data = "cert_id=" . $this->certificateID . "\n";

		foreach($parameters as $k => $v)
		{
			$d[] = "$k=$v";
		}

		$data .= join("\n", $d);

		$dataFile = tempnam($this->tempFileDirectory, 'data');

		$out = fopen("{$dataFile}_data.txt", 'wb');
		fwrite($out, $data);
		fclose($out);

		$out=fopen("{$dataFile}_signed.txt", "w+");

		if (!openssl_pkcs7_sign("{$dataFile}_data.txt", "{$dataFile}_signed.txt", $this->certificate, $this->privateKey, array(), PKCS7_BINARY))
			return false;

		fclose($out);

		$signedData = explode("\n\n", file_get_contents("{$dataFile}_signed.txt"));

		$out = fopen("{$dataFile}_signed.txt", 'wb');
		fwrite($out, base64_decode($signedData[1]));
		fclose($out);

		if (!openssl_pkcs7_encrypt("{$dataFile}_signed.txt", "{$dataFile}_encrypted.txt", $this->paypalCertificate, array(), PKCS7_BINARY))
			return false;

		$encryptedData = explode("\n\n", file_get_contents("{$dataFile}_encrypted.txt"));

		$encryptedText = $encryptedData[1];

		@unlink($dataFile);
		@unlink("{$dataFile}_data.txt");
		@unlink("{$dataFile}_signed.txt");
		@unlink("{$dataFile}_encrypted.txt");

		return "-----BEGIN PKCS7-----\n".$encryptedText."\n-----END PKCS7-----";
	}
}