## /*********************************************
## cpgShop Plugin for Coppermine Photo Gallery
## ********************************************
## written by Thomas Lange
## based on cpgmart by foulu
##
## ********************************************
## * @file $Id$
## * @author $Author$
## * @version $Revision$
## * @lastrevision $Date$
## * @modifiedby $LastChangedBy$
## * @lastmodified $LastChangedDate$
## ********************************************
## cpgShop full Version 1.0.6
## **********************************************/

CREATE TABLE IF NOT EXISTS `CPG_cpgshop_config` (
  name varchar(40) NOT NULL default '',
  value varchar(255) NOT NULL default '',
  PRIMARY KEY  (`name`)
  ) ENGINE=MyISAM COMMENT='Used to store the CPGShop configuration';

# price table
CREATE TABLE IF NOT EXISTS `CPG_cpgshop_price` (
  `pid` INT(11) NOT NULL auto_increment,
  `title` VARCHAR(255) NOT NULL default '',
  `value` DECIMAL(12,2) NOT NULL default '0.00',
  `shipping` DECIMAL(12,2) NOT NULL default '0.00',
  `type` INT(2) NOT NULL default '0',
  `size` INT(11) NOT NULL default '0',
  `currency` CHAR(3) NOT NULL default 'EUR',
  PRIMARY KEY  (`pid`)
) ENGINE=MyISAM COMMENT = 'Stores CPGShop price elements' ;

# price set table
CREATE TABLE IF NOT EXISTS `CPG_cpgshop_priceset` (
	`pid` INT(11) NOT NULL auto_increment,
	`title` VARCHAR(255) NOT NULL DEFAULT '',
	`price_array` TEXT NOT NULL DEFAULT '',
	PRIMARY KEY (`pid`)
) ENGINE=MyISAM COMMENT = 'Stores the CPGShop price groups (sets)' ;

# option table
CREATE TABLE IF NOT EXISTS `CPG_cpgshop_option` (
  `oid` INT(11) NOT NULL auto_increment,
  `title` varchar(255) NOT NULL default '',
  `title_array` TEXT NOT NULL DEFAULT '',
  `value_array` TEXT NOT NULL DEFAULT '',
  `currency` VARCHAR(4) NOT NULL default 'EUR',
  `hasprice` ENUM('Y','N') NOT NULL default 'N',
  PRIMARY KEY (`oid`)
) ENGINE=MyISAM COMMENT = 'Stores CPGShop option elements' ;

# option set table
CREATE TABLE IF NOT EXISTS `CPG_cpgshop_optionset` (
	`oid` INT(11) NOT NULL auto_increment,
	`title` VARCHAR(255) NOT NULL DEFAULT '',
	`option_array` TEXT NOT NULL DEFAULT '',
	PRIMARY KEY (`oid`)
) ENGINE=MyISAM COMMENT = 'Stores the CPGShop option groups (sets)' ;

# countries to ship to table
CREATE TABLE IF NOT EXISTS `CPG_cpgshop_country` (
	`cid` INT(11) NOT NULL auto_increment,
	`english_name` VARCHAR(255) NOT NULL DEFAULT '',
	`native_name` VARCHAR(255) NOT NULL DEFAULT '',
	`abbr` VARCHAR(255) NOT NULL DEFAULT '',
  	`shipping` DECIMAL(12,2) NOT NULL default '0.00',
  	`currency` VARCHAR(4) NOT NULL default 'EUR',
  	`type` INT(2) NOT NULL default '0',
	PRIMARY KEY (`cid`)
) ENGINE=MyISAM COMMENT = 'CPGShop shipping and countries to ship to' ;

# order table
CREATE TABLE IF NOT EXISTS `CPG_cpgshop_order` (
  `oid` INT(11) NOT NULL auto_increment,
  `user_id` INT(11) NOT NULL default '0',
  `user_name` VARCHAR(255) NOT NULL default '',
  `gross` DECIMAL(12,2) NOT NULL default '0.00',
  `item_count` INT(11) NOT NULL default '0',
  `cart` TEXT NOT NULL,
  `profile` TEXT NOT NULL,
  `time` INT(11) NOT NULL default '0',
  `dtime` INT(11) NOT NULL default '0',
  `dpwd` VARCHAR(100) NOT NULL default '',
  `status` CHAR(10) NOT NULL default '',
  `txnid` VARCHAR(255) NOT NULL default '',
  `payment` VARCHAR(32) NOT NULL default '',
  `delivery` VARCHAR(32) NOT NULL default '',
  `tax` FLOAT(3,2) NOT NULL default '0.00',
  `log` TEXT NOT NULL,
  `note` TEXT NOT NULL,
  `hash` VARCHAR(32) NOT NULL default '',
  `tos` TINYINT(1) NOT NULL default '0',
  `cdown` TINYINT(1) NOT NULL default '0',
  `cship` TINYINT(1) NOT NULL default '0',
  `paid` TINYINT(1) NOT NULL default '0',
  `sent` TINYINT(1) NOT NULL default '0',
  `sentd` TINYINT(1) NOT NULL default '0',
  `printed` TINYINT(1) NOT NULL default '0',
  `new` TINYINT(1) NOT NULL default '1',
  `archive` TINYINT(1) NOT NULL default '1',
  PRIMARY KEY  (`oid`),
  KEY `user_id` (`user_id`)
) ENGINE=MyISAM COMMENT = 'CPGShop order table' ;

# shipping and billing addresses | type == 1 -> shipping | type == 0 -> billing
# if bridged, billing saved here, if coppermine -> address saved in users table... required fields verification whilst registering, unfortunately the profile edit doesn't check when editing -> whilst checkout we have a look if elements are missing
CREATE TABLE IF NOT EXISTS `CPG_cpgshop_address` (
  	`sid` INT(11) NOT NULL auto_increment,
  	`user_id` INT(11) NOT NULL default '0',
  	`type` INT(2) NOT NULL default '0',
	`title` VARCHAR(25) NOT NULL DEFAULT '',
	`surename` VARCHAR(255) NOT NULL DEFAULT '',
	`lastname` VARCHAR(255) NOT NULL DEFAULT '',
	`street` VARCHAR(255) NOT NULL DEFAULT '',
	`city` VARCHAR(255) NOT NULL DEFAULT '',
	`zip` VARCHAR(255) NOT NULL DEFAULT '',
	`state` VARCHAR(255) NOT NULL DEFAULT '',
	`phone` VARCHAR(255) NOT NULL DEFAULT '',
	`country` VARCHAR(255) NOT NULL DEFAULT '',
	PRIMARY KEY (`sid`),
  	KEY `user_id` (`user_id`)
) ENGINE=MyISAM COMMENT = 'CPGShop shipping address and billing address (if bridged)' ;

# option set table
CREATE TABLE IF NOT EXISTS `CPG_cpgshop_discount` (
	`did` INT(11) NOT NULL auto_increment,
	`number` VARCHAR(255) NOT NULL DEFAULT '',
  	`discount` VARCHAR(255) NOT NULL default '0.00',
  	`currency` VARCHAR(4) NOT NULL default 'EUR',
  	`valid` TINYINT(1) NOT NULL default '0',
  	`expires` INT(11) NOT NULL default '0',
  	`created` INT(11) NOT NULL default '0',
	`user_id` INT(11) NOT NULL default '0',
	`order_id` INT(11) NOT NULL default '0',
	PRIMARY KEY (`did`),
	KEY `order_id` (`number`)
) ENGINE=MyISAM COMMENT = 'Stores the random discount codes' ;

# option set table
CREATE TABLE IF NOT EXISTS `CPG_cpgshop_docs` (
  `name` VARCHAR(40) NOT NULL default '',
  `text` TEXT NOT NULL,
  PRIMARY KEY  (name)
) ENGINE=MyISAM COMMENT = 'Used to store all document templates';

CREATE TABLE `CPG_cpgshop_paypal_log` (
  `id` int(11) NOT NULL auto_increment,
  `invoice` int(11) NOT NULL default '0',
  `pp_fee` DECIMAL(12,2) NOT NULL default '0.00',
  `pp_currency` VARCHAR(4) NOT NULL default 'EUR',
  `log` TEXT NOT NULL,
  PRIMARY KEY (`id`, `invoice`)
) ENGINE=MyISAM COMMENT = 'Stores the PayPal IPN log';

CREATE TABLE `CPG_cpgshop_cart` (
  `cid` int(11) NOT NULL auto_increment,
  `user_id` INT(11) NOT NULL default '0',
  `cart` MEDIUMBLOB,
  `save` int(2) NOT NULL default '0',
  `ctime` INT(11) NOT NULL default '0',
  PRIMARY KEY (`cid`)
) ENGINE=MyISAM COMMENT = 'Holds the customers cart';

# config values
#tax_fee_type: for now I just use shop based tax fee (0) -> maybe later I'll add purcheaser country based tax
#general
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_enable', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_currency', 'EUR');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_notify_email', 'noname@test.com');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_notify', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_min_order_enable', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_min_order', '');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_tax_fee_type', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_tax_fee', '19');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_extra_states', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_states_auto_move', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_states_email', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_download_enable', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_free_downloads', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_download_zip', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_download_zip_name', 'Orderid{ORDER_ID}_for_{USER_NAME}');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_del_download_dir', '720');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_pdf_invoice', '1');
#INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_send_pwd', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_show_myorders', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_show_fees_calc', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_tos', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_customer_cancel', '1');
#1.04
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_del_cart_interval', '336');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_enable_cart_save', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_cart_save_max', '10');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_del_saved_cart_interval', '8760');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_cart_after_add', '1');
#paypal
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_enable', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_override', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_test_mode', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_fee_enable', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_fee', '2');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_email', '');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_use_ipn', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_ipn_log', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_ipn_log_file', 'logs/paypal_ipn.log.php');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_ssl_enable', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_ssl_adress', '');
#paypal OpenSSL
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_encrypt_enable', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_encrypt_pubk_paypal', 'paypal_cert.pem');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_encrypt_pubk_own', 'own_pubk.pem');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_encrypt_privk_own', 'own_privk.pem');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_encrypt_path', './plugins/cpgshop/keys/');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_paypal_encrypt_certid', '');
#wire
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_wire_enable', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_wire_override', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_wire_fee_enable', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_wire_fee', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_wire_routing', '000-001-002');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_wire_account', '030330030');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_wire_bank', 'RKB Canada');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_wire_bank_address', '10 West Georgia Street <br>Vancouver, BC V6C 3G1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_wire_swift', 'TEST CATT');
#cod
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_cod_enable', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_cod_override', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_cod_fee_enable', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_cod_fee', '7.90');
#delivery
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_pickup_enable', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_pickup_fee_enable', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_pickup_fee', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_standard_enable', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_standard_fee_enable', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_standard_fee', '3.90');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_express_enable', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_express_fee_enable', '1');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_express_fee', '11.90');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_ups_enable', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_ups_fee_enable', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_ups_fee', '0');
#discount
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_discount_enable', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_discount_min_basket', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_discount_value', '0');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_discount_code', '25');
INSERT INTO `CPG_cpgshop_config` VALUES ('cpgshop_discount_trigger', '999999');

# store pricing data per picture
ALTER TABLE `CPG_pictures` ADD `price` text NOT NULL;
ALTER TABLE `CPG_pictures` ADD `option` text NOT NULL;

# enhance user table with address
ALTER TABLE `CPG_users` ADD `title` varchar(25) NOT NULL default '';
ALTER TABLE `CPG_users` ADD `surename` varchar(255) NOT NULL default '';
ALTER TABLE `CPG_users` ADD `lastname` varchar(255) NOT NULL default '';
ALTER TABLE `CPG_users` ADD `street` varchar(255) NOT NULL default '';
ALTER TABLE `CPG_users` ADD `city` varchar(255) NOT NULL default '';
ALTER TABLE `CPG_users` ADD `zip` varchar(255) NOT NULL default '';
ALTER TABLE `CPG_users` ADD `state` varchar(255) NOT NULL default '';
ALTER TABLE `CPG_users` ADD `phone` varchar(255) NOT NULL default '';
ALTER TABLE `CPG_users` ADD `country` varchar(255) NOT NULL default '';

###############################################
# email templates
###############################################
#shop address - used in checkout emails - invoice
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_checkout_address_txt', 'MyShop

MyStreet 17
Zip City');
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_checkout_address_html', 'MyShop<br>
<br>
MyStreet 17<br>
Zip City<br>');
#checkout emails to admin and user
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_checkout_user_txt', '                                                 MyCity, {DATE}

{SHOP_ADDRESS}

{CUSTOMER_ADDRESS}


Dear {TITLE} {LASTNAME},
thank you for your order with the ID {ORDER_ID}. For your convenience it is listed again below.


{CART}


If you have not already paid, use the following information to do so.

{PAYMENT}

{LINK}

Yours sincerly,
{SITENAME}');
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_checkout_user_html', '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
</head>
<body>
<div>
<p align="right">
MyCity, {DATE}
</p>
<br /><br />
<p align="left">
{SHOP_ADDRESS}
</p>
<br />
<br />
<p align="left">
{CUSTOMER_ADDRESS}
</p>
<br />
<br />
<br />
<p align="left">
Dear {TITLE} {LASTNAME},<br/>
thank you for your order with the ID {ORDER_ID}. For your convenience it is listed again below.
</p>
<br />
<br />
<table>
{CART}
</table>
<br />
<br />
<p>
 If you have not already paid, use the following information to do so.
<br />
<br />
{PAYMENT}
<br />
<br />
{LINK}
<br />
<br />
</p>
<p align="left">
Yours sincerly,
<br />
{SITENAME}
<br />
</p>
</div>
</body>
</html>');
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_checkout_user_pdf', '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<style type="text/css">
body { margin-left:50px; margin-right:40px; margin-top:40px; margin-bottom:40px }
</style>
</head>
<body>
<div>
<p align="right">
MyCity, {DATE}
</p>
<br /><br />
<p align="left">
{SHOP_ADDRESS}
</p>
<br />
<br />
<p align="left">
{CUSTOMER_ADDRESS}
</p>
<br />
<br />
<br />
<p align="left">
<strong>Invoice: {ORDER_ID}</strong>
</p>
<br />
<br />
<br />
<table width="100%">
{CART}
</table>
<br />
</div>
</body>
</html>');
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_checkout_subj_user', 'Thank you for your order');
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_checkout_subj_admin', 'A user just made an order');
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_checkout_admin_txt', 'Hello Admin,
today, {DATE}, the user {USER_NAME} with the user_id {USER_ID} made an order. His address is:

{CUSTOMER_ADDRESS}

he purcheased the following:

{CART}

You may view the order in the admin area. The order_id is {ADMIN_LINK}

Regards,
{SITENAME}
');
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_checkout_admin_html', '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
</head>
<body>
<div>
<p align="left">
Hello Admin,
</p>
<br />
<p align="left">
today, {DATE}, the user {USER_NAME} with the user_id {USER_ID} made an order. His address is:
<br />
<br />
{CUSTOMER_ADDRESS}
<br />
<br />
he purcheased the following:
</p>
<br />
<br />
<table>
{CART}
</table>
<br />
<br />
<p>
You may view the order in the admin area. The order_id is {ADMIN_LINK}
<br />
<br />
</p>
<p align="left">
Regards,<br>
{SITENAME}<br />
</p>
</div>
</body>
</html>');
#email to admin - IPN log
INSERT INTO `CPG_cpgshop_docs` VALUES ('ipn_admin_mail_txt', '
The following data was received from PayPal:
from {PAYER_EMAIL} on {DATE}
Details:
');
#download folder htaccess
INSERT INTO `CPG_cpgshop_docs` VALUES ('htaccess', 'AuthName        "This is your download folder. Please use the username and password you received in our email."
AuthType        Basic
AuthUserFile    {HTPASSWD_PATH}

<Limit GET POST>
require valid-user
</Limit>');
#send user the download email
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_password_user_subj', 'Your download password');
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_password_user_txt', 'Hello {TITLE} {NAME},

your order has been processed and we have created a download directory for you.

Please click the following link and your ordered items will be copied into your download directory. You can access this directory using:
Username: {USER_NAME}
Password: {PASSWORD}

{LINK}

Best regards,
{SITENAME}');
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_password_user_html', '
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
</head>
<body>
<div>
<p align="left">
Hello {TITLE} {NAME},
</p>
<p align="left">
your order has been processed and we have created a download directory for you.
<br /><br />
Please click the following link and your ordered items will be copied into your download directory. You can access this directory using:
</p>
<br />
<p align="left">
Username: {USER_NAME}
<br />
Password: {PASSWORD}
</p>
<br />
<p>
<a href="{LINK}">Download your items</a>
<br />
<br />
</p>
<p align="left">
Best regards,<br>
{SITENAME}<br />
</p>
</div>
</body>
</html>'
);
#state changed paid
INSERT INTO `CPG_cpgshop_docs` VALUES ('state_change_paid_subj', 'Status of your order has changed to: in process');
INSERT INTO `CPG_cpgshop_docs` VALUES ('state_change_paid_txt', 'Hello {TITLE} {SURENAME} {LASTNAME},

we have received your payment for the order with the ID {ORDER_ID}. The status has been changed to \'in process\'.

You also can see the details of your order in the order history.

{LINK}

Best regards,
{SITENAME}');
INSERT INTO `CPG_cpgshop_docs` VALUES ('state_change_paid_html', '
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
</head>
<body>
<div>
<p align="left">
Hello {TITLE} {SURENAME} {LASTNAME},
</p>
<p align="left">
we have received your payment for the order with the ID {ORDER_ID}. The status has been changed to \'in process\'.
<br /><br />
You also can see the details of your order in the order history.
</p>
<br />
<p>
<a href="{LINK}">Order history</a>
<br />
<br />
</p>
<p align="left">
Best regards,<br>
{SITENAME}<br />
</p>
</div>
</body>
</html>'
);
#state changed printed
INSERT INTO `CPG_cpgshop_docs` VALUES ('state_change_printed_subj', 'Status of your order has changed to: printed');
INSERT INTO `CPG_cpgshop_docs` VALUES ('state_change_printed_txt', 'Hello {TITLE} {SURENAME} {LASTNAME},

the photos from your order with the ID {ORDER_ID} have been printed. The status of this order now has changed to \'printed\'.

You also can see the details of your order in the order history.

{LINK}

Best regards,
{SITENAME}');
INSERT INTO `CPG_cpgshop_docs` VALUES ('state_change_printed_html', '
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
</head>
<body>
<div>
<p align="left">
Hello {TITLE} {SURENAME} {LASTNAME},
</p>
<p align="left">
the photos from your order with the ID {ORDER_ID} have been printed. The status of this order now has changed to \'printed\'.
<br /><br />
You also can see the details of your order in the order history.
</p>
<br />
<p>
<a href="{LINK}">Order history</a>
<br />
<br />
</p>
<p align="left">
Best regards,<br>
{SITENAME}<br />
</p>
</div>
</body>
</html>'
);
#state changed sent
INSERT INTO `CPG_cpgshop_docs` VALUES ('state_change_sent_subj', 'Status of your order has changed to: sent');
INSERT INTO `CPG_cpgshop_docs` VALUES ('state_change_sent_txt', 'Hello {TITLE} {SURENAME} {LASTNAME},

your order with the ID {ORDER_ID} has shipped. The status of this order has been changed to \'sent\'.

You also can see the details of your order in the order history.

{LINK}

Best regards,
{SITENAME}');
INSERT INTO `CPG_cpgshop_docs` VALUES ('state_change_sent_html', '
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
</head>
<body>
<div>
<p align="left">
Hello {TITLE} {SURENAME} {LASTNAME},
</p>
<p align="left">
your order with the ID {ORDER_ID} has shipped. The status of this order has been changed to \'sent\'.
<br /><br />
You also can see the details of your order in the order history.
</p>
<br />
<p>
<a href="{LINK}">Order history</a>
<br />
<br />
</p>
<p align="left">
Best regards,<br>
{SITENAME}<br />
</p>
</div>
</body>
</html>'
);
#state changed downloaded
INSERT INTO `CPG_cpgshop_docs` VALUES ('state_change_downloaded_subj', 'Status of your order has changed to: downloaded');
INSERT INTO `CPG_cpgshop_docs` VALUES ('state_change_downloaded_txt', 'Hello {TITLE} {SURENAME} {LASTNAME},

we have created a download folder for your order with the ID {ORDER_ID}. The status of this order has been changed to \'downloaded\'.

You also can see the details of your order in the order history.

{LINK}

Best regards,
{SITENAME}');
INSERT INTO `CPG_cpgshop_docs` VALUES ('state_change_downloaded_html', '
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
</head>
<body>
<div>
<p align="left">
Hello {TITLE} {SURENAME} {LASTNAME},
</p>
<p align="left">
we have created a download folder for your order with the ID {ORDER_ID}. The status of this order has been changed to \'downloaded\'.
<br /><br />
You also can see the details of your order in the order history.
</p>
<br />
<p>
<a href="{LINK}">Order history</a>
<br />
<br />
</p>
<p align="left">
Best regards,<br>
{SITENAME}<br />
</p>
</div>
</body>
</html>'
);

#checkout thank you page
INSERT INTO `CPG_cpgshop_docs` VALUES ('checkout_thankyou_page', '
<strong>Thank you for your purchase.</strong><br />
We appreciate your business. Your order will be processed immediatley upon payment approval. At that time, an email confirmation will be sent to the email address you provided.<br />
In case you clicked the order button by mistake you can undo the order as long it is not in process. Have a look at your order history for that.<br /><br />
<br /><br />
{GATEWAY_INFO}
<br /><br />
Best regards,<br />
{SITENAME}<br />
'
);

INSERT INTO `CPG_cpgshop_docs` VALUES ('checkout_thankyou_paypal', '
If you have chosen to pay by Paypal please click the \'Pay by PayPal\' button below.
You may pay your order via your PayPal account (if you have one), or simply create a FREE PayPal account to pay with any major credit card or directly from your bank account.<br />
');
INSERT INTO `CPG_cpgshop_docs` VALUES ('checkout_thankyou_wire', '
Please find the bank wire transfer information below and please make sure to cover all related charges on your end.<br />
');
INSERT INTO `CPG_cpgshop_docs` VALUES ('checkout_thankyou_cod', '
You have chosen to pay by delivery. We will send you a notification when we ship your order.
');
#terms of service
INSERT INTO `CPG_cpgshop_docs` VALUES ('tos', '
<html>
<head>
<title>Terms of service</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
</head>
<body>
<div>
<p align="left">
<strong>Terms of service</strong>
</p>
<p align="left">
<ol>
<li>text
<li>more
<li>even more
</ol>
</p>
</div>
</body>
</html>'
);


#cancel order email
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_cancel_order_user_subj', 'You have successfully cancelled your order');
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_cancel_order_user_txt', 'Hello {TITLE} {NAME},

we are sorry that we weren\'t able to fullfill your wishes and hence see you cancel your order with the ID {OID}.

Hopefully you soon find new items on our site that are from interest for you. So we are looking forward to your coming orders.

Best regards,
{SITENAME}');
INSERT INTO `CPG_cpgshop_docs` VALUES ('email_cancel_order_user_html', '
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
</head>
<body>
<div>
<p align="left">
Hello {TITLE} {NAME},
</p>
<p align="left">
we are sorry that we weren\'t able to fullfill your wishes and hence see you cancel your order with the ID {OID}.
<br /><br />
Hopefully you soon find new items on our site that are from interest for you. So we are looking forward to your coming orders.
</p>
<br />
<br />
<p align="left">
Best regards,<br>
{SITENAME}<br />
</p>
</div>
</body>
</html>'
);